@@ -81,8 +81,9 @@ class Config(object):
             files = sorted(os.listdir(path))
 
             for file in files:
-                filepath = path + os.sep + file
-                conf = Config.__load_from_path(conf, filepath)
+                if file.endswith('.conf'):
+                    filepath = path + os.sep + file
+                    conf = Config.__load_from_path(conf, filepath)
 
             return conf
 
@@ -239,7 +240,7 @@ class Config(object):
                 result.append('## %s' % wrapped)
                 if key in cls.class_aliases:
                     result.append('## Aliases: %s' % ', '.join(cls.class_aliases[key]))
-                result.append('## Defaults to: %s' % value)
+                result.append('## Defaults to: %s' % format_value(value))
                 result.append('#%s = %s' % (key, format_value(value)))
             result.append('')
             result.append(SEPARATOR * MAX_LEN)
